Module substudy::video
[−]
[src]
Tools for working with video files.
Structs
| Extraction |
Information about what kind of data we want to extract. |
| Fraction |
A wrapper around |
| Stream |
An individual content stream within a video. |
| Video |
Represents a video file on disk. |
Enums
| CodecType |
Individual streams inside a video are labelled with a codec type. |
| ExtractionSpec |
What kind of data do we want to extract, and from what position in the video clip? |